@@ -59,6 +59,8 @@
 #'
 #' @param analysis_var Analysis variable
 #'
+#'   `r lifecycle::badge("deprecated")` Please use `set_values_to` instead.
+#'
 #'   The specified variable is set to the value of `analysis_value` for the new
 #'   observations.
 #'
@@ -105,6 +107,8 @@
 #'
 #' @param analysis_value Definition of the analysis value
 #'
+#'  `r lifecycle::badge("deprecated")` Please use `set_values_to` instead.
+#'
 #'   An expression defining the analysis value (`AVAL`) of the new parameter is
 #'   expected. The values of variables of the parameters specified by
 #'   `parameters` can be accessed using `<variable name>.<parameter code>`,
@@ -117,21 +121,35 @@
 #' @param set_values_to Variables to be set
 #'
 #'   The specified variables are set to the specified values for the new
-#'   observations. For example `exprs(PARAMCD = "MAP")` defines the parameter
-#'   code for the new parameter.
+#'   observations. The values of variables of the parameters specified by
+#'   `parameters` can be accessed using `<variable name>.<parameter code>`. For
+#'   example
+#'   ```
+#'   exprs(
+#'     AVAL = (AVAL.SYSBP + 2 * AVAL.DIABP) / 3,
+#'     PARAMCD = "MAP"
+#'   )
+#'   ```
+#'   defines the analysis value and parameter code for the new parameter.
+#'
+#'   Variable names in the expression must not contain more than one dot.
 #'
 #'   *Permitted Values:* List of variable-value pairs
 #'
+#' @param keep_nas Keep observations with `NA`s
+#'
+#'   If the argument is set to `TRUE`, observations are added even if some of
+#'   the values contributing to the computed value are `NA`.
+#'
 #' @details For each group (with respect to the variables specified for the
 #'   `by_vars` parameter) an observation is added to the output dataset if the
 #'   filtered input dataset (`dataset`) or the additional dataset
 #'   (`dataset_add`) contains exactly one observation for each parameter code
 #'   specified for `parameters`.
 #'
-#'   For the new observations `AVAL` is set to the value specified by
-#'   `analysis_value` and the variables specified for `set_values_to` are set to
-#'   the provided values. The values of the other variables of the input dataset
-#'   are set to `NA`.
+#'   For the new observations the variables specified for `set_values_to` are
+#'   set to the provided values. The values of the other variables of the input
+#'   dataset are set to `NA`.
 #'
 #' @return The input dataset with the new parameter added. Note, a variable will only
 #'    be populated in the new parameter rows if it is specified in `by_vars`.
@@ -144,6 +162,8 @@
 #'
 #' @examples
 #' library(tibble)
+#' library(dplyr)
+#' library(lubridate)
 #'
 #' # Example 1: Derive MAP
 #' advs <- tribble(
@@ -162,8 +182,8 @@
 #'   advs,
 #'   by_vars = exprs(USUBJID, VISIT),
 #'   parameters = c("SYSBP", "DIABP"),
-#'   analysis_value = (AVAL.SYSBP + 2 * AVAL.DIABP) / 3,
 #'   set_values_to = exprs(
+#'     AVAL = (AVAL.SYSBP + 2 * AVAL.DIABP) / 3,
 #'     PARAMCD = "MAP",
 #'     PARAM = "Mean Arterial Pressure (mmHg)",
 #'     AVALU = "mmHg"
@@ -187,8 +207,8 @@
 #'   advs,
 #'   by_vars = exprs(USUBJID, VISIT),
 #'   parameters = "WEIGHT",
-#'   analysis_value = AVAL.WEIGHT / (AVAL.HEIGHT / 100)^2,
 #'   set_values_to = exprs(
+#'     AVAL = AVAL.WEIGHT / (AVAL.HEIGHT / 100)^2,
 #'     PARAMCD = "BMI",
 #'     PARAM = "Body Mass Index (kg/m^2)",
 #'     AVALU = "kg/m^2"
@@ -198,7 +218,7 @@
 #' )
 #'
 #' # Example 3: Using data from an additional dataset and other variables than AVAL
-#' qs <- tibble::tribble(
+#' qs <- tribble(
 #'   ~USUBJID, ~AVISIT,   ~QSTESTCD, ~QSORRES, ~QSSTRESN,
 #'   "1",      "WEEK 2",  "CHSF112", NA,               1,
 #'   "1",      "WEEK 2",  "CHSF113", "Yes",           NA,
@@ -208,29 +228,58 @@
 #'   "1",      "WEEK 4",  "CHSF114", NA,               1
 #' )
 #'
-#' adchsf <- tibble::tribble(
-#'   ~USUBJID, ~AVISIT,  ~PARAMCD, ~QSORRES, ~QSSTRESN, ~AVAL,
-#'   "1",      "WEEK 2", "CHSF12", NA,       1,             6,
-#'   "1",      "WEEK 2", "CHSF14", NA,       1,             6,
-#'   "1",      "WEEK 4", "CHSF12", NA,       2,            12,
-#'   "1",      "WEEK 4", "CHSF14", NA,       1,             6
-#' )
+#' adchsf <- tribble(
+#'   ~USUBJID, ~AVISIT,  ~PARAMCD, ~QSSTRESN, ~AVAL,
+#'   "1",      "WEEK 2", "CHSF12", 1,             6,
+#'   "1",      "WEEK 2", "CHSF14", 1,             6,
+#'   "1",      "WEEK 4", "CHSF12", 2,            12,
+#'   "1",      "WEEK 4", "CHSF14", 1,             6
+#' ) %>%
+#'   mutate(QSORRES = NA_character_)
 #'
 #' derive_param_computed(
 #'   adchsf,
 #'   dataset_add = qs,
 #'   by_vars = exprs(USUBJID, AVISIT),
 #'   parameters = exprs(CHSF12, CHSF13 = QSTESTCD %in% c("CHSF113", "CHSF213"), CHSF14),
-#'   analysis_value = case_when(
-#'     QSORRES.CHSF13 == "Not applicable" ~ 0,
-#'     QSORRES.CHSF13 == "Yes" ~ 38,
-#'     QSORRES.CHSF13 == "No" ~ if_else(
-#'       QSSTRESN.CHSF12 > QSSTRESN.CHSF14,
-#'       25,
-#'       0
-#'     )
+#'   set_values_to = exprs(
+#'     AVAL = case_when(
+#'       QSORRES.CHSF13 == "Not applicable" ~ 0,
+#'       QSORRES.CHSF13 == "Yes" ~ 38,
+#'       QSORRES.CHSF13 == "No" ~ if_else(
+#'         QSSTRESN.CHSF12 > QSSTRESN.CHSF14,
+#'         25,
+#'         0
+#'       )
+#'     ),
+#'     PARAMCD = "CHSF13"
+#'   )
+#' )
+#'
+#' # Example 4: Computing more than one variable
+#' adlb_tbilialk <- tribble(
+#'   ~USUBJID, ~PARAMCD, ~AVALC, ~ADTM,        ~ADTF,
+#'   "1",      "ALK2",   "Y",    "2021-05-13", NA_character_,
+#'   "1",      "TBILI2", "Y",    "2021-06-30", "D",
+#'   "2",      "ALK2",   "Y",    "2021-12-31", "M",
+#'   "2",      "TBILI2", "N",    "2021-11-11", NA_character_,
+#'   "3",      "ALK2",   "N",    "2021-04-03", NA_character_,
+#'   "3",      "TBILI2", "N",    "2021-04-04", NA_character_
+#' ) %>%
+#'   mutate(ADTM = ymd(ADTM))
+#'
+#' derive_param_computed(
+#'   dataset_add = adlb_tbilialk,
+#'   by_vars = exprs(USUBJID),
+#'   parameters = c("ALK2", "TBILI2"),
+#'   set_values_to = exprs(
+#'     AVALC = if_else(AVALC.TBILI2 == "Y" & AVALC.ALK2 == "Y", "Y", "N"),
+#'     ADTM = pmax(ADTM.TBILI2, ADTM.ALK2),
+#'     ADTF = if_else(ADTM == ADTM.TBILI2, ADTF.TBILI2, ADTF.ALK2),
+#'     PARAMCD = "TB2AK2",
+#'     PARAM = "TBILI > 2 times ULN and ALKPH <= 2 times ULN"
 #'   ),
-#'   set_values_to = exprs(PARAMCD = "CHSF13")
+#'   keep_nas = TRUE
 #' )
 derive_param_computed <- function(dataset = NULL,
                                   dataset_add = NULL,
@@ -241,9 +290,9 @@ derive_param_computed <- function(dataset = NULL,
                                   set_values_to,
                                   filter = NULL,
                                   constant_by_vars = NULL,
-                                  constant_parameters = NULL) {
+                                  constant_parameters = NULL,
+                                  keep_nas = FALSE) {
   assert_vars(by_vars)
-  analysis_var <- assert_symbol(enexpr(analysis_var))
   assert_vars(constant_by_vars, optional = TRUE)
   assert_data_frame(dataset, required_vars = by_vars, optional = TRUE)
   assert_data_frame(dataset_add, optional = TRUE)
@@ -252,7 +301,26 @@ derive_param_computed <- function(dataset = NULL,
   if (!is.null(set_values_to$PARAMCD) && !is.null(dataset)) {
     assert_param_does_not_exist(dataset, set_values_to$PARAMCD)
   }
-  analysis_value <- enexpr(analysis_value)
+  assert_logical_scalar(keep_nas)
+  ### BEGIN DEPRECATION
+  if (!missing(analysis_var)) {
+    deprecate_warn(
+      "0.12.0",
+      "derive_param_computed(analysis_var = )",
+      "derive_param_computed(set_values_to = )"
+    )
+  }
+  analysis_var <- assert_symbol(enexpr(analysis_var))
+
+  if (!missing(analysis_value)) {
+    deprecate_warn(
+      "0.12.0",
+      "derive_param_computed(analysis_value = )",
+      "derive_param_computed(set_values_to = )"
+    )
+    set_values_to <- exprs(!!analysis_var := !!enexpr(analysis_value), !!!set_values_to)
+  }
+  ### END DEPRECATION
 
   parameters <- assert_parameters_argument(parameters)
   constant_parameters <- assert_parameters_argument(constant_parameters, optional = TRUE)
@@ -270,7 +338,7 @@ derive_param_computed <- function(dataset = NULL,
     data_source,
     by_vars = by_vars,
     parameters = parameters,
-    analysis_value = !!analysis_value,
+    set_values_to = set_values_to,
     filter = !!filter
   )
   hori_data <- hori_return[["hori_data"]]
@@ -284,7 +352,7 @@ derive_param_computed <- function(dataset = NULL,
       data_source,
       by_vars = constant_by_vars,
       parameters = constant_parameters,
-      analysis_value = !!analysis_value,
+      set_values_to = set_values_to,
       filter = !!filter
     )[["hori_data"]]
 
@@ -296,13 +364,17 @@ derive_param_computed <- function(dataset = NULL,
   }
 
   # add analysis value (AVAL) and parameter variables, e.g., PARAMCD
-  hori_data <- hori_data %>%
+  if (!keep_nas) {
     # keep only observations where all analysis values are available
-    filter(!!!parse_exprs(map_chr(
-      analysis_vars_chr,
-      ~ str_c("!is.na(", .x, ")")
-    ))) %>%
-    process_set_values_to(exprs(!!analysis_var := !!analysis_value)) %>%
+    hori_data <- filter(
+      hori_data,
+      !!!parse_exprs(map_chr(
+        analysis_vars_chr,
+        ~ str_c("!is.na(", .x, ")")
+      ))
+    )
+  }
+  hori_data <- hori_data %>%
     process_set_values_to(set_values_to) %>%
     select(-all_of(analysis_vars_chr[str_detect(analysis_vars_chr, "\\.")]))
 
@@ -323,8 +395,7 @@ derive_param_computed <- function(dataset = NULL,
 #' @return The `parameters` argument (converted to a list of symbol, if it is a
 #'   character vector)
 #'
-#' @keywords other_advanced
-#' @family other_advanced
+#' @keywords internal
 assert_parameters_argument <- function(parameters, optional = TRUE) {
   assert_logical_scalar(optional)
   if (optional && is.null(parameters)) {
@@ -370,14 +441,14 @@ assert_parameters_argument <- function(parameters, optional = TRUE) {
 #'
 #'   *Permitted Values:* A character vector of `PARAMCD` values or a list of expressions
 #'
-#' @param analysis_value
+#' @param set_values_to
 #'
 #'   All variables of the form `<variable>.<parameter>` like `AVAL.WEIGHT` are
 #'   added to the input dataset. They are set to the value of the variable for
 #'   the parameter. E.g., `AVAL.WEIGHT` is set to the value of `AVAL` where
 #'   `PARAMCD == "WEIGHT"`.
 #'
-#'   *Permitted Values:* An unquoted expression
+#'   *Permitted Values:* A list of expressions
 #'
 #' @param filter Filter condition used for restricting the input dataset
 #'
@@ -390,17 +461,16 @@ assert_parameters_argument <- function(parameters, optional = TRUE) {
 #'   variables specified for `by_vars` and all variables of the form
 #'   `<variable>.<parameter>` occurring in `analysis_value`.
 #'
-#' @keywords other_advanced
-#' @family other_advanced
+#' @keywords internal
 get_hori_data <- function(dataset,
                           by_vars,
                           parameters,
-                          analysis_value,
+                          set_values_to,
                           filter) {
   assert_vars(by_vars)
   assert_data_frame(dataset, required_vars = by_vars)
   parameters <- assert_parameters_argument(parameters)
-  analysis_value <- enexpr(analysis_value)
+  assert_expr_list(set_values_to)
   filter <- assert_filter_cond(enexpr(filter), optional = TRUE)
 
   # determine parameter values
@@ -468,13 +538,13 @@ get_hori_data <- function(dataset,
   )
 
   # horizontalize data, e.g., AVAL for PARAMCD = "PARAMx" -> AVAL.PARAMx
-  analysis_vars <- extract_vars(analysis_value)
+  analysis_vars <- flatten(map(unname(set_values_to), extract_vars))
   analysis_vars_chr <- vars2chr(analysis_vars)
   multi_dot_names <- str_count(analysis_vars_chr, "\\.") > 1
   if (any(multi_dot_names)) {
     abort(
       paste(
-        "The `analysis_value` argument contains variable names with more than on dot:",
+        "The `set_values_to` argument contains variable names with more than on dot:",
         enumerate(analysis_vars_chr[multi_dot_names]),
         sep = "\n"
       )
@@ -507,6 +577,6 @@ get_hori_data <- function(dataset,
   list(
     hori_data = bind_rows(hori_data) %>%
       select(!!!by_vars, any_of(analysis_vars_chr)),
-    analysis_vars_chr = analysis_vars_chr
+    analysis_vars_chr = analysis_vars_chr[str_detect(analysis_vars_chr, "\\.")]
   )
 }
