@@ -1,7 +1,7 @@
 ## Test 1: Test that call_derivation generates expected summary  ----
 # ---- call_derivation Test 1:  Test that call_derivation generates expected summary ----
 test_that("call_derivation Test 1:  Test that call_derivation generates expected summary", {
-  input <- admiral.test::admiral_vs[sample(seq_len(nrow(admiral.test::admiral_vs)), 1000), ]
+  input <- pharmaversesdtm::vs[sample(seq_len(nrow(pharmaversesdtm::vs)), 1000), ]
 
   expected_output <- input %>%
     derive_summary_records(
@@ -58,7 +58,7 @@ test_that("call_derivation Test 1:  Test that call_derivation generates expected
 ## Test 2: Test that call_derivation generates expected imputation  ----
 # ---- call_derivation Test 2: Test that call_derivation generates expected imputation ----
 test_that("call_derivation Test 2: Test that call_derivation generates expected imputation", {
-  input <- admiral.test::admiral_ae[sample(seq_len(nrow(admiral.test::admiral_ae)), 1000), ] %>%
+  input <- pharmaversesdtm::ae[sample(seq_len(nrow(pharmaversesdtm::ae)), 1000), ] %>%
     left_join(admiral_adsl, by = "USUBJID")
 
   expected_output <- input %>%
@@ -94,7 +94,7 @@ test_that("call_derivation Test 2: Test that call_derivation generates expected
 ## Test 3: Test that Error is thrown if ... has no arguments  ----
 # ---- call_derivation Test 3: Test that Error is thrown if ... has no arguments ----
 test_that("call_derivation Test 3: Test that Error is thrown if ... has no arguments", {
-  input <- admiral.test::admiral_ae[sample(seq_len(nrow(admiral.test::admiral_ae)), 1000), ] %>%
+  input <- pharmaversesdtm::ae[sample(seq_len(nrow(pharmaversesdtm::ae)), 1000), ] %>%
     left_join(admiral_adsl, by = "USUBJID")
 
   expect_error(
@@ -112,7 +112,7 @@ test_that("call_derivation Test 3: Test that Error is thrown if ... has no argum
 ## Test 4: Error is thrown if ... arguments are not properly named ----
 # ---- call_derivation Test 4: Error is thrown if ... arguments are not properly named ----
 test_that("call_derivation Test 4: Error is thrown if ... arguments are not properly named", {
-  input <- admiral.test::admiral_ae[sample(seq_len(nrow(admiral.test::admiral_ae)), 1000), ] %>%
+  input <- pharmaversesdtm::ae[sample(seq_len(nrow(pharmaversesdtm::ae)), 1000), ] %>%
     left_join(admiral_adsl, by = "USUBJID")
 
   expect_error(
@@ -132,7 +132,7 @@ test_that("call_derivation Test 4: Error is thrown if ... arguments are not prop
 ## Test 5: Error is thrown params is empty ----
 # ---- call_derivation Test 5: Error is thrown params is empty ----
 test_that("call_derivation Test 5: Error is thrown params is empty", {
-  input <- admiral.test::admiral_ae[sample(seq_len(nrow(admiral.test::admiral_ae)), 1000), ] %>%
+  input <- pharmaversesdtm::ae[sample(seq_len(nrow(pharmaversesdtm::ae)), 1000), ] %>%
     left_join(admiral_adsl, by = "USUBJID")
 
   expect_error(
@@ -152,7 +152,7 @@ test_that("call_derivation Test 5: Error is thrown params is empty", {
 ## Test 6: Error is thrown if passed params are not properly named ----
 # ---- call_derivation Test 6: Error is thrown if passed params are not properly named ----
 test_that("call_derivation Test 6: Error is thrown if passed params are not properly named", {
-  input <- admiral.test::admiral_ae[sample(seq_len(nrow(admiral.test::admiral_ae)), 1000), ] %>%
+  input <- pharmaversesdtm::ae[sample(seq_len(nrow(pharmaversesdtm::ae)), 1000), ] %>%
     left_join(admiral_adsl, by = "USUBJID")
 
   expect_error(
@@ -173,7 +173,7 @@ test_that("call_derivation Test 6: Error is thrown if passed params are not prop
 ## Test 7: Error is thrown if `...` arguments are not properly named ----
 # ---- call_derivation Test 7: Error is thrown if `...` arguments are not properly named ----
 test_that("call_derivation Test 7: Error is thrown if `...` arguments are not properly named", {
-  input <- admiral.test::admiral_ae[sample(seq_len(nrow(admiral.test::admiral_ae)), 1000), ] %>%
+  input <- pharmaversesdtm::ae[sample(seq_len(nrow(pharmaversesdtm::ae)), 1000), ] %>%
     left_join(admiral_adsl, by = "USUBJID")
 
   expect_error(
